{% load static i18n %}


<tbody id="log-files-data" class="w-full dark:bg-slate-800">
{% if filenames %}
    {% for filename in filenames %}
        <tr class="hover:bg-gray-100 dark::bg-gray-500 dark:bg-slate-700 dark:text-white">
            <td class="w-full cursor-pointer break-all dark:text-white dark:border-gray-100/50"
                hx-get="{% url 'log_inspector:log_entries' filename=filename %}"
                hx-trigger="click"
                hx-target="#log-entries-table"
                hx-swap="outerHTML"
                @click="updateFileName($event); isFileSelected = true; live=false">
                {{ filename }}
            </td>
        </tr>
    {% endfor %}
{% else %}
    <tr class="hover:bg-gray-100 dark::bg-gray-500 dark:bg-slate-700 dark:text-white dark:border-gray-100/50">
        <td class="w-full cursor-pointer break-all dark:text-white"
            colspan="2">
            {% trans 'No entries!' %}
        </td>
    </tr>
{% endif %}
</tbody>