from django.conf import settings

LOG_INSPECTOR_FILES = getattr(settings, "LOG_INSPECTOR_FILES", [])
LOG_INSPECTOR_FILES_PATTERN = getattr(settings, "LOG_INSPECTOR_FILES_PATTERN", "*.log*")
LOG_INSPECTOR_FILES_DIR = getattr(settings, "LOG_INSPECTOR_FILES_DIR", "logs/")
LOG_INSPECTOR_PAGE_LENGTH = getattr(settings, "LOG_INSPECTOR_PAGE_LENGTH", 25)
LOG_INSPECTOR_MAX_READ_LINES = getattr(settings, "LOG_INSPECTOR_MAX_READ_LINES", 1000)
LOG_INSPECTOR_FILE_LIST_TITLE = getattr(settings, "LOG_INSPECTOR_FILE_LIST_TITLE", None)
LOG_INSPECTOR_FILE_LIST_STYLES = getattr(settings, "LOG_INSPECTOR_FILE_LIST_STYLES", None)
LOG_INSPECTOR_PATTERNS = getattr(
    settings,
    "LOG_INSPECTOR_PATTERNS",
    ["[INFO]", "[DEBUG]", "[WARNING]", "[ERROR]", "[CRITICAL]"],
)
LOG_INSPECTOR_EXCLUDE_TEXT_PATTERN = getattr(
    settings, "LOG_INSPECTOR_EXCLUDE_TEXT_PATTERN", None
)
